@@ -1,3 +1,5 @@
+#ifndef __TP_STREAM_ENGINE_CHANNEL_H__
+#define __TP_STREAM_ENGINE_CHANNEL_H__
 
 #include <glib-object.h>
 
@@ -54,3 +56,5 @@ void tp_stream_engine_channel_error (
 
 G_END_DECLS
 
+#endif /* __TP_STREAM_ENGINE_CHANNEL_H__ */
+
