@@ -79,6 +79,22 @@ cb_fs_session_error (
     "Media.SessionHandler::Error");
 }
 
+static void
+destroy_cb (DBusGProxy *proxy, gpointer user_data)
+{
+  TpStreamEngineSession *self = TP_STREAM_ENGINE_SESSION (user_data);
+  TpStreamEngineSessionPrivate *priv = SESSION_PRIVATE (self);
+
+  if (priv->session_handler_proxy)
+    {
+      DBusGProxy *tmp;
+
+      tmp = priv->session_handler_proxy;
+      priv->session_handler_proxy = NULL;
+      g_object_unref (tmp);
+    }
+}
+
 static void
 new_media_stream_handler (DBusGProxy *proxy, gchar *stream_handler_path,
                           guint id, guint media_type, guint direction,
@@ -117,6 +133,8 @@ tp_stream_engine_session_dispose (GObject *object)
 
   if (priv->session_handler_proxy)
     {
+      DBusGProxy *tmp;
+
       g_debug ("%s: disconnecting signals from session handler proxy",
         G_STRFUNC);
 
@@ -124,8 +142,12 @@ tp_stream_engine_session_dispose (GObject *object)
           priv->session_handler_proxy, "NewStreamHandler",
           G_CALLBACK (new_media_stream_handler), self);
 
-      g_object_unref (priv->session_handler_proxy);
+      g_signal_handlers_disconnect_by_func (
+          priv->session_handler_proxy, destroy_cb, self);
+
+      tmp = priv->session_handler_proxy;
       priv->session_handler_proxy = NULL;
+      g_object_unref (tmp);
     }
 
   if (priv->fs_session)
@@ -237,6 +259,9 @@ tp_stream_engine_session_go (
     session_handler_path,
     TP_IFACE_MEDIA_SESSION_HANDLER);
 
+  g_signal_connect (priv->session_handler_proxy, "destroy",
+      G_CALLBACK (destroy_cb), self);
+
   if (!priv->session_handler_proxy)
     {
       g_critical ("couldn't get proxy for session");
