@@ -112,11 +112,16 @@ stop_telephony_event (DBusGProxy *proxy, gpointer user_data);
 static void
 stop_stream (TpStreamEngineStream *self);
 
+static void
+destroy_cb (DBusGProxy *proxy, gpointer user_data);
+
 static void
 _remove_video_sink (TpStreamEngineStream *stream, GstElement *sink)
 {
   TpStreamEngine *engine;
   GstElement *pipeline;
+  gboolean retval;
+  GstStateChangeReturn ret;
 
   DEBUG (stream, "removing video sink");
 
@@ -125,10 +130,23 @@ _remove_video_sink (TpStreamEngineStream *stream, GstElement *sink)
 
   engine = tp_stream_engine_get ();
   pipeline = tp_stream_engine_get_pipeline (engine);
-  gst_element_set_state (sink, GST_STATE_NULL);
+
+  gst_object_ref (sink);
+
+  retval = gst_bin_remove (GST_BIN (pipeline), sink);
+  g_assert (retval == TRUE);
+
+  ret = gst_element_set_state (sink, GST_STATE_NULL);
+  g_assert (ret != GST_STATE_CHANGE_FAILURE);
+
+  if (ret == GST_STATE_CHANGE_ASYNC) {
+    ret = gst_element_get_state (sink, NULL, NULL, 5*GST_SECOND);
+    g_assert (ret != GST_STATE_CHANGE_FAILURE);
+  }
 
   DEBUG (stream, "sink refcount: %d", GST_OBJECT_REFCOUNT_VALUE(sink));
-  gst_bin_remove (GST_BIN (pipeline), sink);
+
+  gst_object_unref (sink);
 }
 
 static void
@@ -145,6 +163,8 @@ tp_stream_engine_stream_dispose (GObject *object)
 
   if (priv->stream_handler_proxy)
     {
+      DBusGProxy *tmp;
+
       dbus_g_proxy_disconnect_signal (priv->stream_handler_proxy,
           "AddRemoteCandidate", G_CALLBACK (add_remote_candidate), stream);
 
@@ -175,8 +195,13 @@ tp_stream_engine_stream_dispose (GObject *object)
       dbus_g_proxy_disconnect_signal (priv->stream_handler_proxy,
           "StopTelephonyEvent", G_CALLBACK (stop_telephony_event), stream);
 
-      g_object_unref (priv->stream_handler_proxy);
+      g_signal_handlers_disconnect_by_func (priv->stream_handler_proxy,
+          G_CALLBACK (destroy_cb), stream);
+
+
+      tmp = priv->stream_handler_proxy;
       priv->stream_handler_proxy = NULL;
+      g_object_unref (tmp);
     }
 
   if (priv->fs_stream)
@@ -752,6 +777,7 @@ static void
 stop_stream (TpStreamEngineStream *self)
 {
   TpStreamEngineStreamPrivate *priv = STREAM_PRIVATE (self);
+  GstElement *sink = NULL;
 
   if (!priv->fs_stream)
     return;
@@ -759,12 +785,13 @@ stop_stream (TpStreamEngineStream *self)
   DEBUG (self, "calling stop on farsight stream %p", priv->fs_stream);
 
   if (self->media_type == FARSIGHT_MEDIA_TYPE_VIDEO)
-    {
-      GstElement *sink = farsight_stream_get_sink (priv->fs_stream);
-      _remove_video_sink (self, sink);
-    }
+    sink = farsight_stream_get_sink (priv->fs_stream);
 
   farsight_stream_stop (priv->fs_stream);
+
+  if (sink)
+    _remove_video_sink (self, sink);
+
 }
 
 static void
@@ -1094,6 +1121,7 @@ make_sink (TpStreamEngineStream *stream, guint media_type)
           g_assert (GST_IS_BIN (sink));
           engine = tp_stream_engine_get ();
           gst_bin_add (GST_BIN (tp_stream_engine_get_pipeline (engine)), sink);
+          gst_element_set_state (sink, GST_STATE_PLAYING);
           g_assert (sink);
         }
       else
@@ -1112,6 +1140,22 @@ make_sink (TpStreamEngineStream *stream, guint media_type)
 }
 
 
+static void
+destroy_cb (DBusGProxy *proxy, gpointer user_data)
+{
+  TpStreamEngineStream *stream = TP_STREAM_ENGINE_STREAM (user_data);
+  TpStreamEngineStreamPrivate *priv = STREAM_PRIVATE (stream);
+
+  if (priv->stream_handler_proxy)
+    {
+      DBusGProxy *tmp = priv->stream_handler_proxy;
+
+      priv->stream_handler_proxy = NULL;
+      g_object_unref (tmp);
+    }
+}
+
+
 gboolean
 tp_stream_engine_stream_go (
   TpStreamEngineStream *stream,
@@ -1146,6 +1190,9 @@ tp_stream_engine_stream_go (
       return FALSE;
     }
 
+  g_signal_connect (priv->stream_handler_proxy, "destroy",
+      G_CALLBACK (destroy_cb), stream);
+
   priv->fs_stream = farsight_session_create_stream (
     fs_session, media_type, direction);
 
