@@ -40,7 +40,6 @@
 
 #include "tp-stream-engine.h"
 #include "tp-stream-engine-signals-marshal.h"
-#include "misc-signals-marshal.h"
 
 #ifdef USE_INFOPRINT
 #include "statusbar-gen.h"
@@ -70,33 +69,33 @@ register_dbus_signal_marshallers()
 {
   /*register a marshaller for the NewMediaStreamHandler signal*/
   dbus_g_object_register_marshaller
-    (misc_marshal_VOID__BOXED_UINT_UINT_UINT, G_TYPE_NONE,
+    (tp_stream_engine_marshal_VOID__BOXED_UINT_UINT_UINT, G_TYPE_NONE,
      DBUS_TYPE_G_OBJECT_PATH, G_TYPE_UINT, G_TYPE_UINT, G_TYPE_UINT,
      G_TYPE_INVALID);
 
   /*register a marshaller for the NewMediaSessionHandler signal*/
   dbus_g_object_register_marshaller
-    (misc_marshal_VOID__BOXED_STRING, G_TYPE_NONE,
+    (tp_stream_engine_marshal_VOID__BOXED_STRING, G_TYPE_NONE,
      DBUS_TYPE_G_OBJECT_PATH, G_TYPE_STRING, G_TYPE_INVALID);
 
   /*register a marshaller for the AddRemoteCandidate signal*/
   dbus_g_object_register_marshaller
-    (misc_marshal_VOID__STRING_BOXED, G_TYPE_NONE,
+    (tp_stream_engine_marshal_VOID__STRING_BOXED, G_TYPE_NONE,
      G_TYPE_STRING, TP_TYPE_TRANSPORT_LIST, G_TYPE_INVALID);
 
   /*register a marshaller for the SetActiveCandidatePair signal*/
   dbus_g_object_register_marshaller
-    (misc_marshal_VOID__STRING_STRING, G_TYPE_NONE,
+    (tp_stream_engine_marshal_VOID__STRING_STRING, G_TYPE_NONE,
      G_TYPE_STRING, G_TYPE_STRING, G_TYPE_INVALID);
 
   /*register a marshaller for the SetRemoteCandidateList signal*/
   dbus_g_object_register_marshaller
-    (misc_marshal_VOID__BOXED, G_TYPE_NONE,
+    (g_cclosure_marshal_VOID__BOXED, G_TYPE_NONE,
      TP_TYPE_CANDIDATE_LIST, G_TYPE_INVALID);
 
   /*register a marshaller for the SetRemoteCodecs signal*/
   dbus_g_object_register_marshaller
-    (misc_marshal_VOID__BOXED, G_TYPE_NONE,
+    (g_cclosure_marshal_VOID__BOXED, G_TYPE_NONE,
      TP_TYPE_CODEC_LIST, G_TYPE_INVALID);
 }
 
@@ -334,11 +333,13 @@ tp_stream_engine_make_video_sink (TpStreamEngine *obj, gboolean is_preview)
           g_debug ("setting qos to FALSE");
           g_object_set (G_OBJECT (sink), "qos", FALSE, NULL);
         }
+#ifndef MAEMO_OSSO_SUPPORT
       if (g_object_has_property (G_OBJECT (sink), "force-aspect-ratio"))
         {
           g_debug ("setting force-aspect-ratio to TRUE");
           g_object_set (G_OBJECT (sink), "force-aspect-ratio", TRUE, NULL);
         }
+#endif
       /* Setting this will make sure we can have several preview windows using
        * the tee without any queue elements */
       /* Without this, elements linked to the tee just block on prerolling and
@@ -1224,6 +1225,7 @@ bus_sync_handler (GstBus *bus, GstMessage *message, gpointer data)
       g_debug ("setting sync to FALSE");
       g_object_set (G_OBJECT (GST_MESSAGE_SRC (message)), "sync", FALSE, NULL);
     }
+#ifndef MAEMO_OSSO_SUPPORT
   if (g_object_has_property (G_OBJECT (GST_MESSAGE_SRC (message)),
           "force-aspect-ratio"))
     {
@@ -1231,6 +1233,7 @@ bus_sync_handler (GstBus *bus, GstMessage *message, gpointer data)
       g_object_set (G_OBJECT (GST_MESSAGE_SRC (message)), 
           "force-aspect-ratio", TRUE, NULL);
     }
+#endif
 
   gst_message_unref (message);
 
